The branch, master has been updated
       via  dbd8e478469a6eb01f1bada1984f902a51fe65c9 (commit)
      from  ce7bf1083edd5679420d5288ae53a52759e0d51c (commit)

- Log -----------------------------------------------------------------
commit dbd8e478469a6eb01f1bada1984f902a51fe65c9
Author: Nicholas Marriott <nicholas.marri...@gmail.com>
Commit: Nicholas Marriott <nicholas.marri...@gmail.com>

    Do pane resize ioctls once at the end of the server loop rather than
    immediately.
---
 server-client.c |   33 ++++++++++++++++++++++++++++++++-
 window.c        |   18 +-----------------
 2 files changed, 33 insertions(+), 18 deletions(-)

diff --git a/window.c b/window.c
index 4bb5348..5ca1811 100644
--- a/window.c
+++ b/window.c
@@ -855,32 +855,16 @@ window_pane_error_callback(
 void
 window_pane_resize(struct window_pane *wp, u_int sx, u_int sy)
 {
-       struct winsize  ws;
-
        if (sx == wp->sx && sy == wp->sy)
                return;
        wp->sx = sx;
        wp->sy = sy;
 
-       memset(&ws, 0, sizeof ws);
-       ws.ws_col = sx;
-       ws.ws_row = sy;
-
        screen_resize(&wp->base, sx, sy, wp->saved_grid == NULL);
        if (wp->mode != NULL)
                wp->mode->resize(wp, sx, sy);
 
-       if (wp->fd != -1 && ioctl(wp->fd, TIOCSWINSZ, &ws) == -1)
-#ifdef __sun
-               /*
-                * Some versions of Solaris apparently can return an error when
-                * resizing; don't know why this happens, can't reproduce on
-                * other platforms and ignoring it doesn't seem to cause any
-                * issues.
-                */
-               if (errno != EINVAL)
-#endif
-               fatal("ioctl failed");
+       wp->flags |= PANE_RESIZE;
 }
 
 /*


-----------------------------------------------------------------------

Summary of changes:
 server-client.c |   33 ++++++++++++++++++++++++++++++++-
 window.c        |   18 +-----------------
 2 files changed, 33 insertions(+), 18 deletions(-)


hooks/post-receive
diff --git a/server-client.c b/server-client.c
index d9a647e..3c14ff8 100644
--- a/server-client.c
+++ b/server-client.c
@@ -28,6 +28,7 @@
 #include "tmux.h"
 
 void   server_client_check_focus(struct window_pane *);
+void   server_client_check_resize(struct window_pane *);
 void   server_client_check_mouse(struct client *, struct window_pane *);
 void   server_client_repeat_timer(int, short, void *);
 void   server_client_check_exit(struct client *);
@@ -495,7 +496,7 @@ server_client_loop(void)
 
        /*
         * Any windows will have been redrawn as part of clients, so clear
         * their flags now. Also check and update pane focus.
         */
        for (i = 0; i < ARRAY_LENGTH(&windows); i++) {
                w = ARRAY_ITEM(&windows, i);
@@ -505,11 +506,41 @@ server_client_loop(void)
                w->flags &= ~WINDOW_REDRAW;
                TAILQ_FOREACH(wp, &w->panes, entry) {
                        server_client_check_focus(wp);
+                       server_client_check_resize(wp);
                        wp->flags &= ~PANE_REDRAW;
                }
        }
 }
 
+/* Check if pane should be resized. */
+void
+server_client_check_resize(struct window_pane *wp)
+{
+       struct winsize  ws;
+
+       if (wp->fd == -1 || !(wp->flags & PANE_RESIZE))
+               return;
+
+       memset(&ws, 0, sizeof ws);
+       ws.ws_col = wp->sx;
+       ws.ws_row = wp->sy;
+
+       if (ioctl(wp->fd, TIOCSWINSZ, &ws) == -1) {
+#ifdef __sun
+               /*
+                * Some versions of Solaris apparently can return an error when
+                * resizing; don't know why this happens, can't reproduce on
+                * other platforms and ignoring it doesn't seem to cause any
+                * issues.
+                */
+               if (errno != EINVAL)
+#endif
+               fatal("ioctl failed");
+       }
+
+       wp->flags &= ~PANE_RESIZE;
+}
+
 /* Check whether pane should be focused. */
 void
 server_client_check_focus(struct window_pane *wp)
@@ -495,7 +496,7 @@ server_client_loop(void)
        /*
         * Any windows will have been redrawn as part of clients, so clear
-        * their flags now. Also check and update pane focus.
+        * their flags now. Also check pane focus and resize.
         */
        for (i = 0; i < ARRAY_LENGTH(&windows); i++) {
-- 
tmux

------------------------------------------------------------------------------
Everyone hates slow websites. So do we.
Make your web apps faster with AppDynamics
Download AppDynamics Lite for free today:
http://p.sf.net/sfu/appdyn_d2d_feb
_______________________________________________
tmux-cvs mailing list
tmux-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/tmux-cvs

Reply via email to